@@ -211,7 +211,7 @@ class DomainClient(AbstractClient):
 
 
     def CreateDomainRedemption(self, request):
-        """创建赎回订单。
+        """创建赎回订单。需要域名状态为：RedemptionPending：赎回期
 
         :param request: Request instance for CreateDomainRedemption.
         :type request: :class:`tencentcloud.domain.v20180808.models.CreateDomainRedemptionRequest`
@@ -603,6 +603,7 @@ class DomainClient(AbstractClient):
 
     def DescribeCustomDnsHostSet(self, request):
         """查询自定义DNS Host
+        当前域名在任意状态下均可获取(根据域名当前状态，不一定能获取到具体数据)
 
         :param request: Request instance for DescribeCustomDnsHostSet.
         :type request: :class:`tencentcloud.domain.v20180808.models.DescribeCustomDnsHostSetRequest`
@@ -1155,6 +1156,7 @@ class DomainClient(AbstractClient):
 
     def SetDomainAutoRenew(self, request):
         """本接口 ( SetDomainAutoRenew ) 用于设置域名自动续费。
+        当前操作暂不受域名状态限制
 
         :param request: Request instance for SetDomainAutoRenew.
         :type request: :class:`tencentcloud.domain.v20180808.models.SetDomainAutoRenewRequest`
@@ -1177,7 +1179,7 @@ class DomainClient(AbstractClient):
 
 
     def SyncCustomDnsHost(self, request):
-        """同步自定义DNS Host
+        """同步自定义DNS Host，将域名已经设置的host配置数据从注册局同步下来
 
         :param request: Request instance for SyncCustomDnsHost.
         :type request: :class:`tencentcloud.domain.v20180808.models.SyncCustomDnsHostRequest`
